Learn R Programming

ham (version 1.2.0)

co2mcmc: Markov Chain Monte Carlo linear regression estimates of plant's CO2 uptake regressed on ambient carbon dioxide concentrations

Description

Markov Chain Monte Carlo linear regression estimates of plant's CO2 uptake regressed on ambient carbon dioxide concentrations

Usage

co2mcmc

Arguments

Format

co2mcmc

MCMC list of 3 chains with 2000 rows and 4 columns in each of the list elements:

b0

Regression intercept.

b1

Regression coefficient of the carbon dioxide concentration effect.

sigma

Square root of model residual variance.

lp__

Total log unnormalized joint posterior density of the model parameters.

...