Learn R Programming

ham (version 1.2.0)

co2multi: Bayes class object with summarized Markov Chain Monte Carlo estimates of plant's CO2 uptake as a binary variable that is above or below the median level

Description

Bayes class object with summarized Markov Chain Monte Carlo estimates of plant's CO2 uptake as a binary variable that is above or below the median level

Usage

co2multi

Arguments

Format

co2multi

Bayes class list of 7 elements with varying rows and columns in each of the list elements:

Posterior.Summary

Standard element that is NA in this object because it is not applicable to this analysis.

MCMC

Dataframe of 4 combined MCMC chain simulations with 8000 rows and 18 columns. Column 1 is CHAIN indicates the 4 chains, columns 2-13 are 'theta' and indicates each plant's rate of having above the median uptake level, columns 14-17 are 'omega' group rates of 'Type' by 'Treatment', and column 18 is the overall group rate.

Multilevel

Posterior estimate summaries in alphabetical order of plant or group names and numerical order plant or group rates.

Target

Standard element that is NA in this object because it is not applicable to this analysis.

targets

Standard element that is NA in this object because it is not applicable to this analysis.

R2.Summary

Standard element that is NA in this object because it is not applicable to this analysis.

parameter

3 parameter names in the multilevel analysis, 'theta', 'omega', and 'omegaO'.

...