Learn R Programming

ham (version 1.2.0)

losmcmc: Markov Chain Monte Carlo estimates of hospital length of stay from the hosprog data frame

Description

Markov Chain Monte Carlo estimates of hospital length of stay from the hosprog data frame

Usage

losmcmc

Arguments

Format

losmcmc

MCMC list of 4 chains with 5000 rows and 2 columns in each of the list elements:

muOfY

Estimate of the mean parameter.

sigmaOfY

Estimate of the square root of variance parameter.

...